@@ -1,4 +1,8 @@
-from fastapi import FastAPI, APIRouter, Header
+from typing import Any, Callable
+
+from fastapi.types import DecoratedCallable
+from fastapi import APIRouter as FastAPIRouter
+from fastapi import FastAPI, Header
 from fastapi.responses import JSONResponse
 from .model import Model
 from .exceptions import ServingHttpError
@@ -15,6 +19,29 @@ def authn(user_id):
     return True
 
 
+class APIRouter(FastAPIRouter):
+    def api_route(
+            self, path: str, *, include_in_schema: bool = True, **kwargs: Any
+    ) -> Callable[[DecoratedCallable], DecoratedCallable]:
+        if path.endswith("/"):
+            path = path[:-1]
+
+        add_path = super().api_route(
+            path, include_in_schema=include_in_schema, **kwargs
+        )
+
+        alternate_path = path + "/"
+        add_alternate_path = super().api_route(
+            alternate_path, include_in_schema=False, **kwargs
+        )
+
+        def decorator(func: DecoratedCallable) -> DecoratedCallable:
+            add_alternate_path(func)
+            return add_path(func)
+
+        return decorator
+
+
 class ModelServer:
     @classmethod
     def create_application(cls) -> FastAPI:
@@ -29,12 +56,11 @@ class ModelServer:
 
     @classmethod
     def _include_api_route(cls, app: FastAPI, model: Model):
-        api = APIRouter(redirect_slashes=True)
+        api = APIRouter(redirect_slashes=False)
 
-        @api.post("/predict/")
+        @api.post("/predict")
         async def predict(body: dict, kubeflow_userid: str = Header(default=None)):
             if not authn(kubeflow_userid):
-
                 return JSONResponse(
                     status_code=401,
                     content={
@@ -77,4 +103,4 @@ class ModelServer:
         # 加载模型的时候，一些类，需要在uvicorn文件上显式的声明 这显然不友好
 
         # 使用当前方法 目前看来和命令行启动并没有太多的不一样
-        uvicorn.run(app, host="0.0.0.0", port=8089, proxy_headers=True)
+        uvicorn.run(app, host="0.0.0.0", port=8089, proxy_headers=True, forwarded_allow_ips="*")
